=======
Credits
=======

Development Lead
----------------

* Sasha Romijn <github@mxsasha.eu>

Contributors
------------

* Matt Davis <matteius@gmail.com>
* Rainer Koirikivi <rainer@koirikivi.fi>
* Daniel Roy Greenfeld <pydanny@gmail.com>
* @ronnievdc
